/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WarFile.java 1343 2007-05-06 23:41:04Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.ant.archive.file;

import org.apache.tools.ant.Project;
import org.apache.tools.ant.taskdefs.War;
import org.apache.tools.ant.types.FileSet;
import org.objectweb.easybeans.ant.archive.api.IWar;
import org.objectweb.easybeans.ant.archive.info.ArchiveInfo;
import org.objectweb.easybeans.ant.archive.info.WarInfo;

/**
 * Creates a WAR file.
 * @author Florent Benoit
 */
public class WarFile extends War implements IWar {

    /**
     * Reference to the archive info object.
     */
    private ArchiveInfo archiveInfo = null;

    /**
     * Creates an archive for the given project.
     * @param p the given project
     */
    public WarFile(final Project p) {
        super();
        setProject(p);
    }

    /**
     * Sets the information about an archive.
     * @param archiveInfo the object that holds data information.
     */
    public void setArchiveInfo(final ArchiveInfo archiveInfo) {
        this.archiveInfo = archiveInfo;
    }

    /**
     * Sets the information about a war archive.
     * @param warInfo the object that holds data information.
     */
    public void setWarInfo(final WarInfo warInfo) {
        setArchiveInfo(warInfo);
    }

    /**
     * Execute the task.
     */
    @Override
    public void execute() {

        // Deployment descriptor
        if (archiveInfo.getDd() != null) {
            setWebxml(archiveInfo.getDd());
        }

        // dest file
        setDestFile(archiveInfo.getDest());

        // fileset
        for (FileSet fileSet : archiveInfo.getFileSetList()) {
            addFileset(fileSet);
        }


        super.execute();
    }


}
