/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EZBDeployer.java 1329 2007-03-13 10:48:43Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployer.api;

import org.objectweb.easybeans.api.EZBServer;

/**
 * Interface allowing to deploy/undeploy the {@link EZBDeployable} objects.
 * @author Florent Benoit
 */
public interface EZBDeployer {

    /**
     * Receive Embedded instance for this deployer.
     * @param server the given instance of the embedded server.
     */
    void setEmbedded(final EZBServer server);

    /**
     * Deploy a deployable. It can be an EJB jar, EAR, WAR, etc.
     * @param deployable a given deployable
     * @throws EZBDeployerException if the deployment is not done.
     */
    void deploy(final EZBDeployable deployable) throws EZBDeployerException;

    /**
     * Undeploy the given deployable. It can be an EJB jar, EAR, WAR, etc.
     * @param deployable a given deployable to undeploy
     * @throws EZBDeployerException if the undeploy operation fails.
     */
    void undeploy(final EZBDeployable deployable) throws EZBDeployerException;
}
