/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsDeployable.java 1363 2007-05-09 16:37:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployable.impl;

import org.objectweb.easybeans.api.EZBArchive;
import org.objectweb.easybeans.deployer.api.EZBDeployable;

/**
 * Defines the common stuff for the deployable objects.
 * @param <T> the type of the deployable.
 * @author Florent Benoit
 */
public abstract class AbsDeployable<T> implements EZBDeployable<T> {

    /**
     * Archive used for this deployable.
     */
    private EZBArchive archive = null;

    /**
     * Original Deployable (not unpacked).
     */
    private T originalDeployable = null;

    /**
     * Unpacked version of this deployable.
     */
    private T unpackedDeployable = null;

    /**
     * Defines and create a deployable for the given archive.
     * @param archive the given archive.
     */
    public AbsDeployable(final EZBArchive archive) {
        this.archive = archive;
    }

    /**
     * Gets the Archive of this deployable object.
     * @return the archive for this deployable.
     */
    public EZBArchive getArchive() {
        return archive;
    }

    /**
     * @return String representation.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(this.getClass().getSimpleName());
        sb.append("[archive=");
        sb.append(archive.getName());
        sb.append("]");
        return sb.toString();
    }

    /**
     * If the Deployable has been unpacked, return the initial deployable.
     * @return the deployable before it is unpacked.
     */
    public T getOriginalDeployable() {
        return originalDeployable;
    }

    /**
     * If the EAR has been unpacked, return the initial archive.
     * @param originalDeployable the deployable before it is unpacked.
     */
    public void setOriginalDeployable(final T originalDeployable) {
        this.originalDeployable = originalDeployable;
    }

    /**
     * If the Deployable has been unpacked, return the unpacked deployable.
     * @return the unpacked deployable associated to this deployable.
     */
    public T getUnpackedDeployable() {
        return unpackedDeployable;
    }

    /**
     * If the Deployable has been unpacked, sets the unpacked deployable.
     * @param unpackedDeployable the unpacked deployable associated to this deployable.
     */
    public void setUnpackedDeployable(final T unpackedDeployable) {
        this.unpackedDeployable = unpackedDeployable;
    }
}
