/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EJB3EntityResolver.java 1246 2006-12-11 13:55:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.xml.parsing;

import org.objectweb.easybeans.util.xml.SchemaEntityResolver;

/**
 * Entity resolver allowing to find schema within the classloader.
 * @author Florent Benoit
 */
public class EJB3EntityResolver extends SchemaEntityResolver {

    /**
     * Schema prefix.
     */
    public static final String PREFIX = "org/objectweb/easybeans/deployment/xml/schemas/";

    /**
     * Client Schema.
     */
    public static final String CLIENT_SCHEMA = "application-client_5.xsd";

    /**
     * EJB3 Schema.
     */
    public static final String EJB3_SCHEMA = "ejb-jar_3_0.xsd";

    /**
     * EJB 2.1 Schema.
     */
    public static final String EJB2_SCHEMA = "ejb-jar_2_1.xsd";

    /**
     * JAVA EE 5 Schema.
     */
    public static final String JAVAEE5_SCHEMA = "javaee_5.xsd";

    /**
     * J2EE 1.4 Schema.
     */
    public static final String J2EE14_SCHEMA = "j2ee_1_4.xsd";

    /**
     * JAVA EE Web services client Schema.
     */
    public static final String JAVAEE_WEBSERVICES_CLIENT_SCHEMA = "javaee_web_services_client_1_2.xsd";

    /**
     * J2EE Web services client Schema.
     */
    public static final String J2EE_WEBSERVICES_CLIENT_SCHEMA = "j2ee_web_services_client_1_1.xsd";

    /**
     * XML schema.
     */
    public static final String XML_SCHEMA = "xml.xsd";

    /**
     * All schemas.
     */
    public static final String[] ALL_SCHEMAS = new String[] {PREFIX + EJB3_SCHEMA, PREFIX + EJB2_SCHEMA, PREFIX + CLIENT_SCHEMA,
            PREFIX + JAVAEE5_SCHEMA, PREFIX + J2EE14_SCHEMA, PREFIX + JAVAEE_WEBSERVICES_CLIENT_SCHEMA,
            PREFIX + J2EE_WEBSERVICES_CLIENT_SCHEMA, PREFIX + XML_SCHEMA };

    /**
     * Constructor. Finds the XSD with classloader.
     */
    public EJB3EntityResolver() {
        super(ALL_SCHEMAS);
    }

}
